==> ui-framework-elements-4.4.4-sources.jar: gen/displays/templates/GroupingExamplesMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiGrouping from "alexandria-ui-elements/src/displays/components/Grouping";
import UiList from "alexandria-ui-elements/src/displays/components/List";
import UiTextCode from "alexandria-ui-elements/src/displays/components/TextCode";
import UiGroupingComboBox from "alexandria-ui-elements/src/displays/components/GroupingComboBox";
import DisplaysGrouping1Mold from "ui-elements/gen/displays/items/Grouping1Mold";
import DisplaysGrouping2Mold from "ui-elements/gen/displays/items/Grouping2Mold";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import GroupingExamplesMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import GroupingExamplesMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class GroupingExamplesMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new GroupingExamplesMoldNotifier(this);
		this.requester = new GroupingExamplesMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="vertical" spacing="8" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_605552397" layout="horizontal" spacing="24">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1146323456" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_919860790" format="h6" mode="normal" value="No facets">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1976130961" format="filledNoAir" layout="horizontal" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_697088037" format="containerAirMedium" layout="vertical" width="200px" height="-1px" spacing="24">
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1140258110" label="gender" format="whiteBackground" pageSize={5}>
								</UiGrouping>
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a658203683" label="age group" format="whiteBackground" pageSize={5}>
								</UiGrouping>
							</UiBlock>
							<UiList context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1145765181" pageSize={20} itemHeight={60} scrollingMark={true}>
							</UiList>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044179799" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_594416591" mode="normal" language="Html" value="Grouping(collections=list1) gender as Labeled(&quot;gender&quot;)&lt;br/&gt;
							Grouping(collections=list1) ageGroup as Labeled(&quot;age group&quot;)&lt;br/&gt;
							List(itemClass=&quot;io.intino.alexandria.ui.documentation.Person&quot;) list&lt;br/&gt;
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Mold &gt; Item(height=60px,width=30%) groupingMold
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text firstName
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Block(layout=Horizontal, spacing=DP16)
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) gender
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) age as Labeled(&quot;age&quot;)">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1630616717" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a801799209" format="h6" mode="normal" value="ComboBox facet">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1568378750" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a643820272" format="containerAirMedium" layout="horizontal" spacing="24">
								<UiGroupingComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1276914874" label="gender" format="whiteBackground">
								</UiGroupingComboBox>
								<UiGroupingComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1819928601" label="age group" format="whiteBackground">
								</UiGroupingComboBox>
							</UiBlock>
							<UiList context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1986129913" pageSize={20} itemHeight={60} scrollingMark={true}>
							</UiList>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a614098412" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a255315723" mode="normal" language="Html" value="Grouping(collections=list2) gender as Labeled(&quot;gender&quot;) ComboBox&lt;br/&gt;
							Grouping(collections=list2) ageGroup as Labeled(&quot;age group&quot;) ComboBox&lt;br/&gt;
							List(itemClass=&quot;io.intino.alexandria.ui.documentation.Person&quot;) list2&lt;br/&gt;
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Mold &gt; Item(height=60px,width=30%) groupingMold
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text firstName
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Block(layout=Horizontal, spacing=DP16)
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) gender
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) age as Labeled(&quot;age&quot;)">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
				</UiBlock>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1468339739" layout="horizontal" spacing="24">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1820394598" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a357532405" format="h6" mode="normal" value="No facets with many options">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1159115471" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1965767343" format="containerAirMedium" layout="vertical" width="100.0%" height="100.0%" spacing="24">
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_212311475" label="country" format="whiteBackground" pageSize={6}>
								</UiGrouping>
							</UiBlock>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1122570734" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a842256149" mode="normal" language="Html" value="Grouping(collections=empty) country as Labeled(&quot;country&quot;)&lt;br/&gt;">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_257734643" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1451582823" format="h6" mode="normal" value="ComboBox facet with many options">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1341329613" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_805123233" format="containerAirMedium" layout="vertical" width="100.0%" height="100.0%" spacing="24">
								<UiGroupingComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_376631762" label="country" format="whiteBackground">
								</UiGroupingComboBox>
							</UiBlock>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1531141174" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a646356688" mode="normal" language="Html" value="Grouping(collections=empty) country as Labeled(&quot;country&quot;) ComboBox&lt;br/&gt;">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
				</UiBlock>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(GroupingExamplesMold));
DisplayFactory.register("GroupingExamplesMold", withStyles(styles, { withTheme: true })(withSnackbar(GroupingExamplesMold)));

==> ui-framework-elements-4.5.7-sources.jar: gen/displays/templates/GroupingExamplesMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiGrouping from "alexandria-ui-elements/src/displays/components/Grouping";
import UiList from "alexandria-ui-elements/src/displays/components/List";
import UiTextCode from "alexandria-ui-elements/src/displays/components/TextCode";
import UiGroupingComboBox from "alexandria-ui-elements/src/displays/components/GroupingComboBox";
import DisplaysGrouping1Mold from "ui-elements/gen/displays/items/Grouping1Mold";
import DisplaysGrouping2Mold from "ui-elements/gen/displays/items/Grouping2Mold";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import GroupingExamplesMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import GroupingExamplesMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class GroupingExamplesMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new GroupingExamplesMoldNotifier(this);
		this.requester = new GroupingExamplesMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="vertical" spacing="8" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_605552397" layout="horizontal" spacing="24">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1146323456" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_919860790" format="h6" mode="normal" value="No facets">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1976130961" format="filledNoAir" layout="horizontal" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_697088037" format="containerAirMedium" layout="vertical" width="200px" height="-1px" spacing="24">
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1140258110" label="gender" format="whiteBackground" pageSize={5}>
								</UiGrouping>
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a658203683" label="age group" format="whiteBackground" pageSize={5}>
								</UiGrouping>
							</UiBlock>
							<UiList context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1145765181" pageSize={20} itemHeight={60} scrollingMark={true}>
							</UiList>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_2044179799" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_594416591" mode="normal" language="Html" value="Grouping(collections=list1) gender as Labeled(&quot;gender&quot;)&lt;br/&gt;
							Grouping(collections=list1) ageGroup as Labeled(&quot;age group&quot;)&lt;br/&gt;
							List(itemClass=&quot;io.intino.alexandria.ui.documentation.Person&quot;) list&lt;br/&gt;
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Mold &gt; Item(height=60px,width=30%) groupingMold
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text firstName
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Block(layout=Horizontal, spacing=DP16)
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) gender
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) age as Labeled(&quot;age&quot;)">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1630616717" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a801799209" format="h6" mode="normal" value="ComboBox facet">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1568378750" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a643820272" format="containerAirMedium" layout="horizontal" spacing="24">
								<UiGroupingComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1276914874" label="gender" format="whiteBackground">
								</UiGroupingComboBox>
								<UiGroupingComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1819928601" label="age group" format="whiteBackground">
								</UiGroupingComboBox>
							</UiBlock>
							<UiList context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1986129913" pageSize={20} itemHeight={60} scrollingMark={true}>
							</UiList>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a614098412" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a255315723" mode="normal" language="Html" value="Grouping(collections=list2) gender as Labeled(&quot;gender&quot;) ComboBox&lt;br/&gt;
							Grouping(collections=list2) ageGroup as Labeled(&quot;age group&quot;) ComboBox&lt;br/&gt;
							List(itemClass=&quot;io.intino.alexandria.ui.documentation.Person&quot;) list2&lt;br/&gt;
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Mold &gt; Item(height=60px,width=30%) groupingMold
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text firstName
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Block(layout=Horizontal, spacing=DP16)
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) gender
							&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;Text(format=description) age as Labeled(&quot;age&quot;)">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
				</UiBlock>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1672274022" layout="horizontal" spacing="24">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1820394598" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a357532405" format="h6" mode="normal" value="No facets with many options">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1159115471" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1965767343" format="containerAirMedium" layout="vertical" width="100.0%" height="100.0%" spacing="24">
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_212311475" label="country" format="whiteBackground" pageSize={6}>
								</UiGrouping>
							</UiBlock>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1122570734" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a842256149" mode="normal" language="Html" value="Grouping(collections=empty) country as Labeled(&quot;country&quot;)&lt;br/&gt;">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1413455785" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1451582823" format="h6" mode="normal" value="ComboBox facet with many options">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1341329613" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_805123233" format="containerAirMedium" layout="vertical" width="100.0%" height="100.0%" spacing="24">
								<UiGroupingComboBox context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_376631762" label="country" format="whiteBackground">
								</UiGroupingComboBox>
							</UiBlock>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_989173749" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_282161691" mode="normal" language="Html" value="Grouping(collections=empty) country as Labeled(&quot;country&quot;) ComboBox&lt;br/&gt;">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
				</UiBlock>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a346918728" layout="horizontal" spacing="24">
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_852552891" layout="vertical" width="49.0%" height="100.0%">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1579735929" format="h6" mode="normal" value="AttachedTo facet with many options">
						</UiText>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a69178158" format="filledNoAir" layout="vertical" spacing="8">
							<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a1504521189" format="containerAirMedium" layout="vertical" width="100.0%" height="100.0%" spacing="24">
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_411869330" label="country" format="whiteBackground" pageSize={6}>
								</UiGrouping>
								<UiGrouping context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1037234692" label="city" format="whiteBackground" pageSize={6}>
								</UiGrouping>
							</UiBlock>
						</UiBlock>
						<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1164091232" layout="vertical">
							<UiTextCode context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1557276526" mode="normal" language="Html" value="Grouping(collections=empty,pageSize=6) country as Labeled(&quot;country&quot;)
							Grouping(collections=empty,pageSize=6) city as Labeled(&quot;city&quot;) AttachedTo(grouping=country)">
							</UiTextCode>
						</UiBlock>
					</UiBlock>
				</UiBlock>
			</UiBlock>
		);
	}


}

export default withStyles(styles, { withTheme: true })(withSnackbar(GroupingExamplesMold));
DisplayFactory.register("GroupingExamplesMold", withStyles(styles, { withTheme: true })(withSnackbar(GroupingExamplesMold)));
